Dir

Enum Dir 

pub enum Dir {
    S,
    E,
    N,
    W,
}
Cardinal directions enum.

Variants



S

South.



E

East



N

North



W

West

Implementations

Source

impl Dir

pub const fn opposite(self) -> Self

Returns the opposite direction.

pub const fn opposite_mut(&mut self)

Changes the direction to its opposite.

pub const fn rotate_ccw(self) -> Self

Returns the next direction in counter-clockwise rotation.

pub const fn rotate_ccw_mut(&mut self)

Changes the direction to the next one in counter-clockwise rotation.

pub const fn rotate_cw(self) -> Self

Returns the next direction in clockwise rotation.

pub const fn rotate_cw_mut(&mut self)

Changes the direction to the next one in clockwise rotation.