GridMask

Struct GridMask 

pub struct GridMask { /* private fields */ }
Boolean mask for grid-like data.

Implementations

Source

impl GridMask

pub fn new((rows, cols): (usize, usize)) -> Self

Creates a new all-false grid mask with the specified rows and cols.

pub fn set_false(&mut self, pos: Pos) -> bool

Sets the specified pos to false.

Returns true if the value changed, or false if it did not.

pub fn set_true(&mut self, pos: Pos) -> bool

Sets the specified pos to true.

Returns true if the value changed, or false if it did not.

pub fn toggle(&mut self, pos: Pos)

Toggles the specified pos between false and true and vice versa.