Pos

Struct Pos 

pub struct Pos {
    pub x: isize,
    pub y: isize,
}
2-dimensional coordinates struct.

Fields

x: isize

X coordinate.

y: isize

Y coordinate.

Implementations

Source

impl Pos

pub const fn new(x: isize, y: isize) -> Self

Creates a new pos with x and y coordinates.

pub const fn move_dir(&self, dir: Dir) -> Self

Returns a new position after movign towards dir.

pub const fn move_dir_mut(&mut self, dir: Dir)

Changes the position by moving towards dir.

pub const fn in_bounds(&self, bounds: (Self, Self)) -> bool

Checks if the position is within a rectangular region’s bounds (two pos representing two diagonally opposite corners).

pub const fn manhattan_distance(&self, other: Self) -> usize

Calculates the Manhattan distance to other.

pub fn adjacent(&self) -> impl Iterator<Item = Self> + use<>

Returns an iterator of adjacent positions.

pub fn corners(&self) -> impl Iterator<Item = Self> + use<>

Returns an iterator of positions in the corners.

pub fn neighbors(&self) -> impl Iterator<Item = Self> + use<>

Returns an iterator of both adjacent and corner positions.