pub enum Dir {
S,
E,
N,
W,
}Expand description
Cardinal directions enum.
Variants
Implementations
Sourceimpl Dir
impl Dir
Sourcepub const fn opposite_mut(&mut self)
pub const fn opposite_mut(&mut self)
Changes the direction to its opposite.
Sourcepub const fn rotate_ccw(self) -> Self
pub const fn rotate_ccw(self) -> Self
Returns the next direction in counter-clockwise rotation.
Sourcepub const fn rotate_ccw_mut(&mut self)
pub const fn rotate_ccw_mut(&mut self)
Changes the direction to the next one in counter-clockwise rotation.
Sourcepub const fn rotate_cw_mut(&mut self)
pub const fn rotate_cw_mut(&mut self)
Changes the direction to the next one in clockwise rotation.