pub struct GridMask { /* private fields */ }Expand description
Boolean mask for grid-like data.
Implementations
Sourceimpl GridMask
impl GridMask
Sourcepub fn new((rows, cols): (usize, usize)) -> Self
pub fn new((rows, cols): (usize, usize)) -> Self
Creates a new all-false grid mask with the specified rows and cols.
Sourcepub fn set_false(&mut self, pos: Pos) -> bool
pub fn set_false(&mut self, pos: Pos) -> bool
Sets the specified pos to false.
Returns true if the value changed, or false if it did not.